import type { EquTypeTree, EquTypeVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  equTypeExport = '/eims/equType/export',
  equTypeList = '/eims/equType/list',
  equTypeTree = '/eims/equType/tree',
  root = '/eims/equType'
}

/**
 * 查询设备类型列表
 * @param query
 * @returns {*}
 */

export function listEquType(params?: any) {
  return requestClient.get<EquTypeVO[]>(Api.equTypeList, { params });
}

/**
 * 获取设备类型树
 * @returns 部门树数组
 */
export function getEquTypeTree() {
  return requestClient.get<EquTypeTree[]>(Api.equTypeTree);
}

/**
 * 查询设备类型详细
 * @param equTypeId
 */
export function getEquType(equTypeId: ID) {
  return requestClient.get<EquTypeVO>(`${Api.root}/${equTypeId}`);
}

/**
 * 新增设备类型
 * @param data
 */
export function addEquType(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}
/**
 * 修改设备类型
 * @param data
 */
export function updateEquType(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除设备类型
 * @param equTypeId
 */
export function delEquType(equTypeId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${equTypeId}`);
}
/**
 * 导出
 * @param
 */
export function equTypeExport(data: any) {
  return commonExport(Api.equTypeExport, data);
}
